@@ -1,5 +1,6 @@
-#$Id: Query.pm 17639 2012-08-30 04:20:00Z jensenma $
+#$Id: Query.pm 17640 2012-08-30 13:46:38Z jensenma $
 package REST::Neo4p::Query;
+use REST::Neo4p::Path;
 use REST::Neo4p::Exceptions;
 use Carp qw(croak carp);
 use strict;
@@ -43,8 +44,8 @@ sub execute {
     $e->rethrow if ($self->{RaiseError});
     return;
   }
-  elsif ($e = Exception::Class->caught()) {
-    ref $e ? $e->rethrow : die $e;
+  elsif ($@) {
+    ref $@ ? $@->rethrow : die $e;
   }
   $self->{NAME} = $resp && $resp->{columns};
   $self->{NUM_OF_FIELDS} = $resp ? scalar @{$resp->{columns}} : 0;
@@ -218,5 +219,9 @@ L<REST::Neo4p>, L<REST::Neo4p::Agent>.
 
 =head1 LICENSE
 
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
+can redistribute it and/or modify it under the same terms as Perl
+itself.
+
 =cut
 1;
